@@ -6,17 +6,17 @@ It's possible to use multiple types of host pythons to create virtual environmen
 - invoking from an old style virtualenv (<17.0.0)
 - invoking from our own venv
 """
-from __future__ import absolute_import, unicode_literals
 
 import subprocess
 import sys
+from pathlib import Path
+from subprocess import Popen
 
 import pytest
 
 from virtualenv.discovery.py_info import PythonInfo
+from virtualenv.info import IS_WIN
 from virtualenv.run import cli_run
-from virtualenv.util.path import Path
-from virtualenv.util.subprocess import Popen
 
 CURRENT = PythonInfo.current_system()
 
@@ -77,20 +77,27 @@ def old_virtualenv(tmp_path_factory, session_app_data):
             process = Popen(cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
             _, __ = process.communicate()
             assert not process.returncode
+            if result.creator.interpreter.implementation == "PyPy" and IS_WIN:
+                # old virtualenv creates pypy paths wrong on windows, so have to hardcode it
+                return str(old_virtualenv_at / "bin" / "pypy.exe")
             exe_path = CURRENT.discover_exe(session_app_data, prefix=str(old_virtualenv_at)).original_executable
             return exe_path
         except Exception as exception:
-            return RuntimeError("failed to create old virtualenv {}".format(exception))
+            return RuntimeError(f"failed to create old virtualenv {exception}")
 
 
-PYTHON = {"root": root, "venv": venv, "old_virtualenv": old_virtualenv}
+PYTHON = {
+    "root": root,
+    "venv": venv,
+    "old_virtualenv": old_virtualenv,
+}
 
 
 @pytest.fixture(params=list(PYTHON.values()), ids=list(PYTHON.keys()), scope="session")
 def python(request, tmp_path_factory, session_app_data):
     result = request.param(tmp_path_factory, session_app_data)
     if isinstance(result, Exception):
-        pytest.skip("could not resolve interpreter based on {} because {}".format(request.param.__name__, result))
+        pytest.skip(f"could not resolve interpreter based on {request.param.__name__} because {result}")
     if result is None:
-        pytest.skip("requires interpreter with {}".format(request.param.__name__))
+        pytest.skip(f"requires interpreter with {request.param.__name__}")
     return result
