@@ -1,5 +1,3 @@
-from __future__ import absolute_import, unicode_literals
-
 import itertools
 import sys
 from shutil import copy2
@@ -17,7 +15,7 @@ from virtualenv.seed.wheels.embed import BUNDLE_FOLDER, BUNDLE_SUPPORT
 def test_base_bootstrap_via_pip_invoke(tmp_path, coverage_env, mocker, current_fastest, no):
     extra_search_dir = tmp_path / "extra"
     extra_search_dir.mkdir()
-    for_py_version = "{}.{}".format(*sys.version_info[0:2])
+    for_py_version = f"{sys.version_info.major}.{sys.version_info.minor}"
     new = BUNDLE_SUPPORT[for_py_version]
     for wheel_filename in BUNDLE_SUPPORT[for_py_version].values():
         copy2(str(BUNDLE_FOLDER / wheel_filename), str(extra_search_dir))
@@ -25,7 +23,7 @@ def test_base_bootstrap_via_pip_invoke(tmp_path, coverage_env, mocker, current_f
     def _load_embed_wheel(app_data, distribution, for_py_version, version):
         return load_embed_wheel(app_data, distribution, old_ver, version)
 
-    old_ver = "3.4"
+    old_ver = "2.7"
     old = BUNDLE_SUPPORT[old_ver]
     mocker.patch("virtualenv.seed.wheels.bundle.load_embed_wheel", side_effect=_load_embed_wheel)
 
@@ -36,12 +34,14 @@ def test_base_bootstrap_via_pip_invoke(tmp_path, coverage_env, mocker, current_f
                 continue
             if with_version == "embed":
                 expected.add(BUNDLE_FOLDER)
-            elif old[dist] != new[dist]:
+            elif old[distribution] == new[distribution]:
+                expected.add(BUNDLE_FOLDER)
+            else:
                 expected.add(extra_search_dir)
         expected_list = list(
             itertools.chain.from_iterable(["--find-links", str(e)] for e in sorted(expected, key=lambda x: str(x))),
         )
-        found = cmd[-len(expected_list) :]
+        found = cmd[-len(expected_list) :] if expected_list else []
         assert "--no-index" not in cmd
         cmd.append("--no-index")
         assert found == expected_list
@@ -64,9 +64,9 @@ def test_base_bootstrap_via_pip_invoke(tmp_path, coverage_env, mocker, current_f
         str(tmp_path / "app-data"),
     ]
     for dist, version in versions.items():
-        create_cmd.extend(["--{}".format(dist), version])
+        create_cmd.extend([f"--{dist}", version])
     if no:
-        create_cmd.append("--no-{}".format(no))
+        create_cmd.append(f"--no-{no}")
     result = cli_run(create_cmd)
     coverage_env()
 
